context_ref library
Classes
- ContextRef
-
ReadOnlyRef<
T> - A read-only reference to a value that can be bound to a BuildContext.
-
Ref<
T> - A reference to a value that can be bound to a BuildContext.
Extensions
-
AnimationControllerRefAPI
on Ref<
TAnimationController> - ContextInheritRefBindingsAPI on BuildContext
- ContextTickerProviderExt on BuildContext
- ContextUseAPI on BuildContext
-
NullableAnimationControllerRefAPI
on Ref<
TAnimationController?> -
ReadOnlyRefAPI
on ReadOnlyRef<
T> -
RefAPI
on Ref<
T> -
TabControllerRefAPI
on Ref<
TTabController>